@@ -1,10 +1,11 @@
 import pytest
 
-from kupy import BaseClass, base_function
+from kupy import BaseClass, base_function 
+from kupy.logger import logger
+from kupy.config import configs
 
 given = pytest.mark.parametrize
 
-
 @given("fn", [BaseClass(), base_function])
 def test_parameterized(fn):
     assert "hello from" in fn()
@@ -16,3 +17,8 @@ def test_base_function():
 
 def test_base_class():
     assert BaseClass().base_method() == "hello from BaseClass"
+
+def test_find_package_name():
+    logger.info(__name__)
+    pass
+    # assert "kupy" = 
